@@ -2,7 +2,6 @@ from typing import Any
 from typing import Dict
 from typing import List
 from numpy import isnan
-from ..utils import logger
 
 
 def transform_tunable_param(param_and_value: Dict[str, Any]):
@@ -43,7 +42,6 @@ def resort_tunes(tunes: dict, sort_by: str = 'percentage year profit', drop_na:
             if isnan(data[sort_by]):
                 del tunes[key]
     tunes = {k: v for k, v in sorted(tunes.items(), key=lambda x: -x[1][sort_by])}
-    logger.debug('tunes are sorted')
     return tunes
 
 
